@@ -64,6 +64,7 @@ class DiscreteEnv(gym.Env):
 
     #introduce some (short) length (time steps)
     self.horizon=200
+    #self.is_end = False
     
     
     
@@ -77,11 +78,8 @@ class DiscreteEnv(gym.Env):
 #take an action with the environment
 #it returns the next observation, the immediate reward, whether the episode is over (done) and additional information    
 #"action" argument is one value in the range of the action space (logit transform)
-  def step(self, action):
-    
-    #check if horizon is over, otherwise keep on going
-    if self.horizon <= 0:
-        done = True
+  def step(self, action): 
+
       
     data = []
     for self.state in self.dfa.itertuples(index=False):    #self.df.itertuples(index=False):
@@ -110,8 +108,13 @@ class DiscreteEnv(gym.Env):
     Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
 
     self.Ynew_cumul = np.mean(Prob1)
+    
+    reward = 0    
+    #check if horizon is over, otherwise keep on going
+    if self.horizon <= 0:
+      done = True
     reward = self.Ynew_cumul
-               
+      
     self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
  
     #reduce the horizon
@@ -124,7 +127,7 @@ class DiscreteEnv(gym.Env):
 #reset state and horizon    
   def reset(self):
     self.horizon = 200
-    done = False
+    self.done = False
     
     self.dfa = pd.DataFrame(dict(
             Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
